Learn R Programming

NSR (version 0.1.0)

NSR_political_divisions: Get information on political divisions with checklists within the NSR

Description

NSR_political_divisions returns information on political divisions with checklist information present in the NSR.

Usage

NSR_political_divisions(by_country = TRUE, ...)

Value

data.frame containing information on political divisions within the NSR database.

Arguments

by_country

Logical. If TRUE (the default), will return a data.frame of checklists for each country. If FALSE, will return a data.frame of countries for each checklist.

...

Additional parameters passed to internal functions.

Examples

Run this code
if (FALSE) {

#To get a list of all political divisions with comprehensive checklists:
checklists_per_country <- NSR_political_divisions()

#To get a list of all checklists the associated countries, set "by_country" to FALSE
countries_per_checklist <- NSR_political_divisions(by_country=FALSE)

}

Run the code above in your browser using DataLab