if (FALSE) {
#To get a list of all political divisions with comprehensive checklists:
checklists_per_country <- NSR_political_divisions()
#To get a list of all checklists the associated countries, set "by_country" to FALSE
countries_per_checklist <- NSR_political_divisions(by_country=FALSE)
}
Run the code above in your browser using DataLab